@@ -25,8 +25,8 @@
 __revision__ = "__FILE__ __REVISION__ __DATE__ __DEVELOPER__"
 
 """
-Verify the -c option's ability to clean generated Visual Studio 6
-project (.dsp) and solution (.dsw) files.
+Verify the -c option's ability to clean generated Visual Studio 7.1
+project (.vcproj) and solution (.sln) files.
 """
 
 import TestSConsMSVS
@@ -35,23 +35,24 @@ test = TestSConsMSVS.TestSConsMSVS()
 host_arch = test.get_vs_host_arch()
 
 # Make the test infrastructure think we have this version of MSVS installed.
-test._msvs_versions = ['6.0']
+test._msvs_versions = ['7.1']
 
-expected_dspfile = TestSConsMSVS.expected_dspfile_6_0
-expected_dswfile = TestSConsMSVS.expected_dswfile_6_0
+expected_slnfile = TestSConsMSVS.expected_slnfile_7_1
+expected_vcprojfile = TestSConsMSVS.expected_vcprojfile_7_1
 
 test.write('SConstruct', """\
 env=Environment(tools=['msvs'],
-                MSVS_VERSION='6.0',
+                MSVS_VERSION='7.1',
                 HOST_ARCH='%(HOST_ARCH)s')
 
-testsrc = ['test.c']
+testsrc = ['test1.cpp', 'test2.cpp']
 testincs = ['sdk.h']
 testlocalincs = ['test.h']
 testresources = ['test.rc']
 testmisc = ['readme.txt']
 
-p = env.MSVSProject(target = 'Test.dsp',
+p = env.MSVSProject(target = 'Test.vcproj',
+                    MSVS_PROJECT_GUID='%(PROJECT_GUID)s',
                     srcs = testsrc,
                     incs = testincs,
                     localincs = testlocalincs,
@@ -61,43 +62,50 @@ p = env.MSVSProject(target = 'Test.dsp',
                     variant = 'Release',
                     auto_build_solution = 0)
 
-env.MSVSSolution(target = 'Test.dsw',
+env.MSVSSolution(target = 'Test.sln',
                  slnguid = '{SLNGUID}',
                  projects = [p],
                  variant = 'Release')
-"""%{'HOST_ARCH':host_arch})
+""" % {'HOST_ARCH':host_arch, 'PROJECT_GUID': TestSConsMSVS.PROJECT_GUID})
 
-test.run()
+test.run(arguments=".")
 
-test.must_exist(test.workpath('Test.dsp'))
-dsp = test.read('Test.dsp', 'r')
-expect = test.msvs_substitute(expected_dspfile, '6.0', None, 'SConstruct')
+test.must_exist(test.workpath('Test.vcproj'))
+vcproj = test.read('Test.vcproj', 'r')
+expect = test.msvs_substitute(expected_vcprojfile, '7.1', None, 'SConstruct')
 # don't compare the pickled data
-assert dsp[:len(expect)] == expect, test.diff_substr(expect, dsp)
+assert vcproj[:len(expect)] == expect, test.diff_substr(expect, vcproj)
 
-test.must_exist(test.workpath('Test.dsw'))
-dsw = test.read('Test.dsw', 'r')
-expect = test.msvs_substitute(expected_dswfile, '6.0', None, 'SConstruct')
-assert dsw == expect, test.diff_substr(expect, dsw)
+test.must_exist(test.workpath('Test.sln'))
+sln = test.read('Test.sln', 'r')
+expect = test.msvs_substitute(expected_slnfile, '7.1', None, 'SConstruct')
+# don't compare the pickled data
+assert sln[:len(expect)] == expect, test.diff_substr(expect, sln)
 
 test.run(arguments='-c .')
 
-test.must_not_exist(test.workpath('Test.dsp'))
-test.must_not_exist(test.workpath('Test.dsw'))
+test.must_not_exist(test.workpath('Test.vcproj'))
+test.must_not_exist(test.workpath('Test.sln'))
 
 test.run(arguments='.')
 
-test.must_exist(test.workpath('Test.dsp'))
-test.must_exist(test.workpath('Test.dsw'))
+test.must_exist(test.workpath('Test.vcproj'))
+test.must_exist(test.workpath('Test.sln'))
 
-test.run(arguments='-c Test.dsp')
+test.run(arguments='-c Test.vcproj')
 
-test.must_not_exist(test.workpath('Test.dsp'))
-test.must_exist(test.workpath('Test.dsw'))
+test.must_not_exist(test.workpath('Test.vcproj'))
+test.must_exist(test.workpath('Test.sln'))
 
-test.run(arguments='-c Test.dsw')
+test.run(arguments='.')
 
-test.must_not_exist(test.workpath('Test.dsw'))
+test.must_exist(test.workpath('Test.vcproj'))
+test.must_exist(test.workpath('Test.sln'))
+
+test.run(arguments='-c Test.sln')
+
+test.must_not_exist(test.workpath('Test.vcproj'))
+test.must_not_exist(test.workpath('Test.sln'))
 
 test.pass_test()
 
